TODO
====

* Allow to set several times the same config to prepare nth driver of the same
  item, need to generate a unique id
* We probably wants to allow extend config files
* find a proper way to pass user/password...
* Think about object parameter(vs string/int) when setting remote server like,
  Proxy, spend more time to see if it's needs
* document plugable drivers
* I may want to rename capabilities parameter, if it make things confusing
* allow __doc__ key to comment json config file or user should probably
  consider yaml files...